.. AUTO-GENERATED FILE -- DO NOT EDIT!

Module: :mod:`segmentation`
===========================
.. automodule:: skimage.segmentation

.. currentmodule:: skimage.segmentation
.. autosummary::

   skimage.segmentation.active_contour
   skimage.segmentation.chan_vese
   skimage.segmentation.checkerboard_level_set
   skimage.segmentation.circle_level_set
   skimage.segmentation.clear_border
   skimage.segmentation.disk_level_set
   skimage.segmentation.felzenszwalb
   skimage.segmentation.find_boundaries
   skimage.segmentation.flood
   skimage.segmentation.flood_fill
   skimage.segmentation.inverse_gaussian_gradient
   skimage.segmentation.join_segmentations
   skimage.segmentation.mark_boundaries
   skimage.segmentation.morphological_chan_vese
   skimage.segmentation.morphological_geodesic_active_contour
   skimage.segmentation.quickshift
   skimage.segmentation.random_walker
   skimage.segmentation.relabel_sequential
   skimage.segmentation.slic
   skimage.segmentation.watershed



active_contour
--------------

.. autofunction:: skimage.segmentation.active_contour


.. include:: skimage.segmentation.active_contour.examples

chan_vese
---------

.. autofunction:: skimage.segmentation.chan_vese


.. include:: skimage.segmentation.chan_vese.examples

checkerboard_level_set
----------------------

.. autofunction:: skimage.segmentation.checkerboard_level_set


.. include:: skimage.segmentation.checkerboard_level_set.examples

circle_level_set
----------------

.. autofunction:: skimage.segmentation.circle_level_set


.. include:: skimage.segmentation.circle_level_set.examples

clear_border
------------

.. autofunction:: skimage.segmentation.clear_border


.. include:: skimage.segmentation.clear_border.examples

disk_level_set
--------------

.. autofunction:: skimage.segmentation.disk_level_set


.. include:: skimage.segmentation.disk_level_set.examples

felzenszwalb
------------

.. autofunction:: skimage.segmentation.felzenszwalb


.. include:: skimage.segmentation.felzenszwalb.examples

find_boundaries
---------------

.. autofunction:: skimage.segmentation.find_boundaries


.. include:: skimage.segmentation.find_boundaries.examples

flood
-----

.. autofunction:: skimage.segmentation.flood


.. include:: skimage.segmentation.flood.examples

flood_fill
----------

.. autofunction:: skimage.segmentation.flood_fill


.. include:: skimage.segmentation.flood_fill.examples

inverse_gaussian_gradient
-------------------------

.. autofunction:: skimage.segmentation.inverse_gaussian_gradient


.. include:: skimage.segmentation.inverse_gaussian_gradient.examples

join_segmentations
------------------

.. autofunction:: skimage.segmentation.join_segmentations


.. include:: skimage.segmentation.join_segmentations.examples

mark_boundaries
---------------

.. autofunction:: skimage.segmentation.mark_boundaries


.. include:: skimage.segmentation.mark_boundaries.examples

morphological_chan_vese
-----------------------

.. autofunction:: skimage.segmentation.morphological_chan_vese


.. include:: skimage.segmentation.morphological_chan_vese.examples

morphological_geodesic_active_contour
-------------------------------------

.. autofunction:: skimage.segmentation.morphological_geodesic_active_contour


.. include:: skimage.segmentation.morphological_geodesic_active_contour.examples

quickshift
----------

.. autofunction:: skimage.segmentation.quickshift


.. include:: skimage.segmentation.quickshift.examples

random_walker
-------------

.. autofunction:: skimage.segmentation.random_walker


.. include:: skimage.segmentation.random_walker.examples

relabel_sequential
------------------

.. autofunction:: skimage.segmentation.relabel_sequential


.. include:: skimage.segmentation.relabel_sequential.examples

slic
----

.. autofunction:: skimage.segmentation.slic


.. include:: skimage.segmentation.slic.examples

watershed
---------

.. autofunction:: skimage.segmentation.watershed


.. include:: skimage.segmentation.watershed.examples

